//
//  NSData+PCCrypt.h
//  PayControl
//
//  Created by Roman Kolesnichenko on 09.08.16.
//  Copyright © 2016 SafeTech. All rights reserved.
//

#import <Foundation/Foundation.h>

@interface NSData (PCCrypt)

/**
 Hash-based Message Authentication Code - код проверки целостности информации
 https://ru.wikipedia.org/wiki/HMAC
 aelf - должен содержать информацию для которой собственно и считается HMAC
 @param key - секретный ключ (пароль), может быть nil / NSString / NSData
 */
- (NSData*)pc_HMAC_SHA256WithKey:(id)key;

/** @return SHA-256 хеш */
- (NSData*)pc_SHA256Hash;
/** @return SHA-1 хеш */
- (NSData*)pc_SHA1Hash;

/**
 Password-Based Key Derivation Function 2 with HMAC SHA256 — формирование ключа на основе пароля.
 https://ru.wikipedia.org/wiki/PBKDF2
 self - должен содержать пароль
 @param salt - соль NSString или NSData
 @param iteration - количество итераций, положительное целое число
 @param keyLength - результирующая длинна ключа
 */
- (NSData*)pc_PBKDF2_HMAC_SHA256WithSalt:(id)salt iteration:(NSUInteger)iteration keyLength:(NSUInteger)keyLength;

/** Возвращает содержимое NSData в виде шестнадцатиричной строки. Возвращает пустую строку если в NSData нет данных. */
- (NSString*)pc_hexadecimalString;

/** Возвращает экземляр NSData с содержимым на основании переданной шестнадцатиричной строки. */
+ (NSData*)pc_dataWithHexadecimalString:(NSString*)string;

+(NSString*)pc_convertStringToHexadecimal:(NSString*)string;

- (NSData*)pc_trimLeadZeroBytes;

-(NSData*)pc_reverse;

@end
