//
//  PCTransaction.h
//  PayControl
//
//  Created by Roman Kolesnichenko on 22.08.16.
//  Copyright © 2016 SafeTech. All rights reserved.
//

#import "PCQRCode.h"

/** Объект транзакции. Только для чтения. Создается с помощью методов класса: transactionFromQRCode: или  transactionFromQRCodeString: */
@interface PCTransaction : NSObject

/// ****************************************************************************
/// @name Методы класса
/// ****************************************************************************

//+ (nullable instancetype)transactionFromResponceString:(NSString*)responceString;

/** Созадание экземпляра класса из объекта QR кода 
 @param qrCode объект PCTransactionQRCode
 @return Экземпляр PCTransaction
 */
+ (nullable instancetype)transactionFromQRCode:(PCQRCode* _Nonnull)qrCode;

/** Созадание экземпляра класса из строки с валидными данными QR кода 
 @param transactionQRCodeString строка с данными QR кода. 
 @return Экземпляр PCTransaction или nil - если данные в переданной transactionQRCodeString строке не валидны
 */
+ (nullable instancetype)transactionFromQRCodeString:(NSString* _Nonnull)transactionQRCodeString;

/** Созадание экземпляра класса из JSON с валидными данными
 @param transactionJson словарь с данными транзакции.
 @return Экземпляр PCTransaction или nil - если данные в переданной transactionJson строке не валидны
 */
+ (nullable instancetype)transactionFromJson:(NSDictionary* _Nonnull)transactionJson;

/// ****************************************************************************
/// @name Свойства
/// ****************************************************************************

/** Идентификатор прикладной системы */
@property(nonatomic, readonly, nullable) NSString *systemID;

/** Идентификатор пользователя */
@property(nonatomic, readonly, nullable) NSString *userID;

/** Идентификатор транзакции */
@property(nonatomic, readonly, nullable) NSString *transactionID;

/** Предпочитаемый тип подтверждения транзакции */
@property(nonatomic, readonly) PCConfirmationType confirmationType;

/** Длина кода подтверждения */
@property(nonatomic, readonly) NSUInteger codeLength;

/** Текстовая информация из данных транзакции */
@property(nonatomic, readonly, nullable) NSString *messageText;

/** Бинарная информация из данных транзакции */
@property(nonatomic, readonly, nullable) NSString *messageBinaryData;

@end
